@@ -584,19 +584,22 @@ def packageDownloadCheck(pkg, mirrorRepoLoc):
     if os.path.exists(pkgIndexLoc):
         tree = html.parse(pkgIndexLoc)
 
-        # Here parse for the serial number in the comments of the page
-        comments = tree.xpath("//comment()")
-        for c in comments:
-            localSerialMatch = re.search(r"SERIAL ([0-9]*)",
-                                         c.text, re.IGNORECASE)
-            if localSerialMatch:
-                localSerial = localSerialMatch.group(1)
-                break
-        # Next we find the index site serial number for the package
-        if not pkg.isJsonError():
-            indexSerial = pkg.getSerialNumber()
-            if int(indexSerial) > int(localSerial):
-                shouldDownload = True
+        if tree.parser.error_log.last_error is not None:
+            shouldDownload = True
+        else:
+            # Here parse for the serial number in the comments of the page
+            comments = tree.xpath("//comment()")
+            for c in comments:
+                localSerialMatch = re.search(r"SERIAL ([0-9]*)",
+                                             c.text, re.IGNORECASE)
+                if localSerialMatch:
+                    localSerial = localSerialMatch.group(1)
+                    break
+            # Next we find the index site serial number for the package
+            if not pkg.isJsonError():
+                indexSerial = pkg.getSerialNumber()
+                if int(indexSerial) > int(localSerial):
+                    shouldDownload = True
     else:
         if not pkg.isJsonError():
             shouldDownload = True
@@ -885,6 +888,7 @@ def main():
     filesToDownload = []
 
     for pkg in packageList:
+        logger.debug("Checking package: " + pkg.getPackageName())
         if packageDownloadCheck(pkg, mirror_repo_loc):
             logger.debug("Adding to download list: " + pkg.getPackageName())
             packageListToDownload.append(pkg)
